flags

package
v0.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2020 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Version = "Master"

Version of the app. This is set by goreleaser during release builds using the latest git tag.

Functions

This section is empty.

Types

type Config

type Config struct {
	Count    uint
	Name     string
	Out      string
	Throttle uint
	URL      string
}

Config represents the command-line configuration options.

func HandleFlags

func HandleFlags() (c *Config, err error)

HandleFlags parses command line arguments and returns a config.

Jump to